#
# spec file for package SUSEConnect
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           SUSEConnect
Version:        0.3.29
Release:        lp152.2.6.1
%define mod_name suse-connect
%define mod_full_name %{mod_name}-%{version}

# Does not build for i586 and s390 and is not supported on those architectures
ExcludeArch:    %ix86 s390

%if 0%{?fedora} || 0%{?rhel} || 0%{?centos_version}
Requires:       ca-certificates
%else
Requires:       ca-certificates-mozilla
%endif
Requires:       coreutils
Requires:       net-tools
Requires:       util-linux
Requires:       zypper
# Required by the rmt-client-setup script:
Recommends:     gawk
Recommends:     gpg2
Recommends:     grep
# Allows for installing openssl 1.0 without needing to remove SUSEConnect. See bsc#1101470.
%if 0%{?sle_version} < 120200
Recommends:     openssl
%else
Recommends:     openssl(cli)
%endif
Recommends:     sed
Recommends:     curl
Requires:       zypper(auto-agree-with-product-licenses)
%ifarch x86_64 aarch64
Requires:       dmidecode
%endif
Conflicts:      suseRegister, yast2-registration < 3.1.129.7

# In SLE12 GA we had a seperate rubygem-suse-connect package, which we need to obsolete now
%if (0%{?sle_version} > 0 && 0%{?sle_version} < 150000)
Obsoletes:      ruby2.1-rubygem-suse-connect < %{version}
Provides:       ruby2.1-rubygem-suse-connect = %{version}
%endif

# cross-distribution howto: https://en.opensuse.org/openSUSE:Build_Service_cross_distribution_howto
%if 0%{?fedora} || 0%{?rhel} || 0%{?centos_version}
%define ruby_version ruby2.5
%global gem_base /usr/share/gems
%global debug_package %{nil}
%if 0%{?fedora} < 30
%define gem_install_options --bindir %{_bindir}
%else
%define gem_install_options --bindir %{buildroot}%{_bindir}
%endif
BuildRequires:  ruby
BuildRequires:  rubygems
%else
%define ruby_version %{rb_default_ruby_suffix}
%define gem_install_options %{nil}
BuildRequires:  %{ruby_version}
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            https://github.com/SUSE/connect

Source:         %{mod_full_name}.gem
Source1:        %{name}.5
Source2:        %{name}.8
Source3:        %{name}.example
Source4:        %{name}-rpmlintrc
Patch0:         switch_server_cert_location_to_etc.patch

Summary:        Utility to register a system with the SUSE Customer Center
License:        LGPL-2.1
Group:          System/Management
Requires(post): /usr/sbin/update-alternatives


%description
This package provides a command line tool and rubygem library for connecting a
client system to the SUSE Customer Center. It will connect the system to your
product subscriptions and enable the product repositories/services locally.

%prep
for s in %{sources}; do
    cp -p $s .
done
for s in %{patches}; do
    cp -p $s .
done

%build

%install
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_bindir}
gem install --verbose --local --build-root=%{buildroot} --no-user-install -f --no-document %{gem_install_options} ./%{mod_full_name}.gem
mv %{buildroot}%{_bindir}/%{name}* %{buildroot}%{_sbindir}/%{name}
ln -s %{_sbindir}/%{name} %{buildroot}%{_bindir}/%{name}

# system certificate location changed to /etc/pki/trust/anchors/registration_server.pem, see bsc#1130864
# sle_version >= 150200 is matching SLES + Leap >= 15SP2, suse_version >= 1550 is Tumbleweed
%if (0%{?sle_version} >= 150200 || 0%{?suse_version} >= 1550)
patch -d %{buildroot}%{gem_base}/gems/%{mod_full_name} -p1 < switch_server_cert_location_to_etc.patch
%endif

install -D -m 644 %_sourcedir/SUSEConnect.5 %{buildroot}%_mandir/man5/SUSEConnect.5
install -D -m 644 %_sourcedir/SUSEConnect.8 %{buildroot}%_mandir/man8/SUSEConnect.8
install -D -m 644 %_sourcedir/SUSEConnect.example %{buildroot}%_sysconfdir/SUSEConnect.example

touch %{buildroot}%_sysconfdir/SUSEConnect
mkdir -p %{buildroot}%_sysconfdir/zypp/credentials.d/
touch %{buildroot}%_sysconfdir/zypp/credentials.d/SCCcredentials

# replace /usr/bin/env with native ruby path
%if 0%{?suse_version}
    sed -i "1s/.*/#\!\/usr\/bin\/ruby\.%{ruby_version}/" %{buildroot}%{_sbindir}/%{name}
    sed -i "1s/.*/#\!\/usr\/bin\/ruby\.%{ruby_version}/" %{buildroot}%{gem_base}/gems/%{mod_full_name}/bin/%{name}
%endif

%post
if [ -s /etc/zypp/credentials.d/NCCcredentials ] && [ ! -e /etc/zypp/credentials.d/SCCcredentials ]; then
    echo "Imported NCC system credentials to /etc/zypp/credentials.d/SCCcredentials"
    cp /etc/zypp/credentials.d/NCCcredentials /etc/zypp/credentials.d/SCCcredentials
fi

if [ -s /etc/suseRegister.conf ]; then
    reg_server=$(sed -n "s/^[[:space:]]*url[[:space:]]*=[[:space:]]*\(https\?:\/\/[^\/]*\).*/\1/p" /etc/suseRegister.conf)
    # if we have a custom regserver and no SCC config yet, write it
    if [ -n "$reg_server" ] && [ "$reg_server" != "https://secure-www.novell.com" ] && [ ! -e /etc/SUSEConnect ]; then
        echo "Imported /etc/suseRegister.conf registration server url to /etc/SUSEConnect"
        echo "url: $reg_server" > /etc/SUSEConnect
    fi
fi

# remove stale update-alternatives config left by previous split, versioned packaging of SUSEConnect
if update-alternatives --config SUSEConnect  &> /dev/null ; then
  update-alternatives --force --quiet --remove-all SUSEConnect
  ln -fs ../sbin/%{name} %{_bindir}/%{name}
fi

%files
%defattr(-,root,root,-)
%{_sbindir}/SUSEConnect
%{_bindir}/SUSEConnect
%{gem_base}/gems/%{mod_full_name}/
%{gem_base}/cache/%{mod_full_name}.gem
%{gem_base}/specifications/%{mod_full_name}.gemspec

%doc %{_mandir}/man5/SUSEConnect.5.*
%doc %{_mandir}/man8/SUSEConnect.8.*

%config(noreplace) %ghost %{_sysconfdir}/SUSEConnect
%config %{_sysconfdir}/SUSEConnect.example
%config %dir %{_sysconfdir}/zypp/
%config %dir %{_sysconfdir}/zypp/credentials.d/
%config(noreplace) %ghost %{_sysconfdir}/zypp/credentials.d/SCCcredentials

%changelog
* Tue Nov 17 2020 Tamara Schmitz <tamara.schmitz@suse.com>
- Update to 0.3.29
- replace env ruby path with native ruby path during build phase
* Mon Sep 28 2020 Thomas Schmidt <tschmidt@suse.com>
- Recognize more formats when parsing .curlrc for proxy credentials (bsc#1155027)
- Add rpmlintrc to filter false-positive warning about patch not applied
* Mon Aug 31 2020 Thomas Muntaner <tmuntaner@suse.com>
- Update to 0.3.27
- SUSEConnect now ensures that it writes its configuration when it
  encounters errors. This helps in the situation where SUSEConnect
  announces itself, but fails during a later step. Without the saved
  configuration, a system could have credentials, but be unsure which
  registration proxy they're valid for.
* Wed Aug 26 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to 0.3.26
  - Extend the YaST API in order to access to the package search
    functionality (jsc#SLE-9109)
* Tue Jun 30 2020 Thomas Schmidt <tschmidt@suse.com>
- Don't fail de-activation when '-release' package already got removed
* Thu Jan  2 2020 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Update to 0.3.25
- Fix cloud_provider detection on AWS large instances (bsc#1160007)
* Tue Nov  5 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Update to 0.3.24
- Forbid de-registration for on-demand Public Cloud instances (bsc#1155911)
* Mon Oct 14 2019 Thomas Schmidt <tschmidt@suse.com>
- 0.3.23
  fix .spec file to correctly apply switch_server_cert_location_to_etc.patch to SLE15SP2+ (bsc#1130864)
* Mon Sep 30 2019 Thomas Schmidt <tschmidt@suse.com>
- Update to 0.3.22
  switch_server_cert_location_to_etc.patch: add patch to switch server cert path for SLE15.2+ to /etc (bsc#1130864)
* Thu Sep 26 2019 Thomas Schmidt <tschmidt@suse.com>
- Update to 0.3.21
  Fix error on first activation of packagehub extension (bsc#1124318)
* Thu Aug  8 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Update to 0.3.20
- Fix getting the list of installed products when zypper plugins are
  present (bsc#1143635)
* Wed Aug  7 2019 Giovanni Filippetti <giovanni.filippetti@suse.com>
- Update to 0.3.19
  - Fix failing on registered system without arguments (bsc#1144020)
* Wed May 29 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Update to 0.3.18
- Fix base product service removal during de-registration in public clouds (bsc#1136752)
* Tue Apr  2 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Update to 0.3.17
  - Don't try to remove a service during migration if a zypper service
    plugin already exists (bsc#1128969)
* Tue Feb  5 2019 Stephan Kulow <coolo@suse.com>
- Replace --no-ri --no-rdoc with --no-document - these options
  are obsolete since at least ruby 2.1 - and finally removed in
  ruby 2.6
- Only overwrite --bindir on fedora, it will overwrite --buildroot
  (which needs to be combined on newer fedoras)
* Fri Dec  7 2018 fschueller@suse.com
- Update to 0.3.16
  - Show non-enabled extensions with a remark about availability
* Fri Nov 16 2018 fschueller@suse.com
- Update to 0.3.15
  - Output information about registration and de-registration progress
* Fri Nov  9 2018 fschueller@suse.com
- Output proper message when SUSEConnect is called without parameters (bsc#959561)
- Default to https URI when no protocol prefix is provided for --url
- Support transactional-update systems (fate#326482)
* Tue Oct 23 2018 hschmidt@suse.com
- Changed "openssl" recommendation to "openssl(cli)"
  on SLE 12 SP3+ and SLE 15+ (bsc#1101470).
* Mon Oct 22 2018 hschmidt@suse.com
- Update to 0.3.14
  - Fix s390 activation fails due to unavailable 'dmidecode' bsc#1112702
* Fri Sep 28 2018 skotov@suse.com
- Update to 0.3.13
  - Fix migration targets sorting (bsc#1104183)
* Wed Sep  5 2018 tmuntaner@suse.com
- Update to 0.3.12
  - Detect if system is in cloud provider (AWS/Google/Azure)
    (fate#320935)
  - Don't fail when trying to parse an empty body. Fixes bsc#1098220
  - Don't install release packages if they are already present
* Tue Jun 19 2018 tschmidt@suse.com
- Fix .spec file for running SUSEConnect on Fedora28
* Tue Jun  5 2018 wstephenson@suse.com
- Weaken dependencies of rmt-client-setup script to Recommends:
  (bsc#1094348)
- Enhance error message generation
- Add not supported operation exception to PackageSearch API
* Wed May 16 2018 hschmidt@suse.com
- Update to 0.3.11
- Add dependencies needed by the rmt-client-setup script. bsc#1093658
* Mon May  7 2018 hschmidt@suse.com
- Prevent the automatic registration of recommended products that
  are not mirrored by the registration proxy.
* Thu Apr 19 2018 fschnizlein@suse.com
- Update to 0.3.10
  - Fix rollback mechanism on SLE15 systems (bsc#1089320)
* Thu Apr  5 2018 wstephenson@suse.com
- Update to 0.3.9
  - Enable access to package search via gem
  - Don't try to delete directory of nonexistent service files
    (bsc#1086420)
* Tue Mar 13 2018 fschnizlein@suse.com
- Update to 0.3.8
  - Fix list-extensions to show the full SLE 15 tree (bsc#1064264)
  - Enable automatic activation of recommended extensions/modules
  - Automatically deregister all installed extensions/modules when
    deregistering a system
* Tue Jan 30 2018 fschueller@suse.com
- Repackage gem
* Tue Jan 23 2018 fschueller@suse.com
- Remove unnecessary .gz files
* Thu Jan 18 2018 fschueller@suse.com
- Update to 0.3.7
  - virt-create-rootfs connects to SMT server without breaking (bsc#914297)
* Thu Dec 28 2017 hschmidt@suse.com
- Update to 0.3.6
  - Make target_base_product parameter mandatory.
* Mon Dec 18 2017 hschmidt@suse.com
- Update to 0.3.5
  - Add YaST.system_offline_migrations
* Thu Dec 14 2017 tschmidt@suse.com
- Update to version 0.3.4:
  - Packaging improvements (bsc#964013)
* Thu Dec  7 2017 tschmidt@suse.com
- Update to version 0.3.3:
  - Fix SLE15 build
* Mon Oct 16 2017 ikapelyukhin@suse.com
- Properly refresh zypper services when deactivating a product on SMT (bsc#1047153)
* Mon Jun 26 2017 kpimenov@suse.com
- Update to 0.3.2:
  - Fix --namespace parameter persistence (bsc#1044493)
* Thu Jun  8 2017 thutterer@suse.com
- Update to 0.3.1:
  - Fix license auto-agree issue (bsc#1037783)
  - Add missing archs to SLE 12 SP3 build target
* Fri May  5 2017 andrei.shaidurov@suse.com
- Update to 0.3.0:
  - Single product deactivation feature (fate#320572)
* Tue Mar 21 2017 ashaidurov@suse.com
- Update to 0.2.43:
  - RPM spec fix for openSUSE:Factory rpmlint compliance (bsc#1028660)
* Fri Mar  3 2017 thutterer@suse.com
- Update to 0.2.42:
  - Better error message for network request failure (bsc#982630)
  - Fix error message for --product with malformed identifier (bsc#1018190)
  - Fix some errors and formatting in manpages and help output
* Thu Oct  6 2016 thutterer@suse.com
- Update to 0.2.41:
  - Better error message for --list-extensions on unregistered systems
* Tue Sep 13 2016 hschmidt@suse.com
- Update to 0.2.40:
  - Update man page to include the --list-extensions option (bsc#998583)
* Thu Aug 11 2016 thutterer@suse.com
- Update to 0.2.39:
  - Fix for bnc#990475: support for aarch64 hardware info
* Tue Aug  2 2016 thutterer@suse.com
- Update to 0.2.38:
  - Fix for bnc#975484: better error message if SMT is too old
* Tue Jun 21 2016 hschmidt@suse.com
- Update to 0.2.37:
  - Add method to YaST class to get Installer-Updates repositories (fate#319716).
* Wed May 11 2016 ashaidurov@suse.com
- Update to 0.2.36:
  - Fix for bnc#973851: More flexible exit codes handling in internal zypper calls
* Tue Apr  5 2016 ashaidurov@suse.com
- Update to 0.2.35:
  - Fix for bnc#973315: Direct update from <=0.2.27 does not remove /usr/bin symlink
* Thu Mar 10 2016 tschmidt@suse.com
- Update to 0.2.34:
  - Fix for bnc#963996: Do not crash on --list-extensions when connected to SMT
  - Fix for bnc#968245: Do not let zypper attempt to read products from remote locations
* Mon Jan 25 2016 tschmidt@suse.com
- Update to 0.2.33:
  - Re-add SUSEConnect binary to /usr/sbin (bnc#963080)
  - Use `--match-exact` when searching for a product (bnc#952804)
  - Fix fonts on xterm (bnc#957354)
* Wed Dec 16 2015 tschmidt@suse.com
- Update to version 0.2.32: Remove unneeded link in %%post which caused a warning (bnc#946183)
* Fri Nov 20 2015 kpimenov@novell.com
- Update to version 0.2.31 (bnc#946183)
  - Drop url-implies-writeconfig.diff; it is included in upstream since commit 2ef5aa
  - Correct RPM group
  - Include SCCcredentials file as a ghost entry
  - Further packaging improvements
* Thu Nov 19 2015 kpimenov@suse.com
- Update to version 0.2.30
  - New packaging spec. One `SUSEConnect` package to rule them all (bnc#951671)
  - Update manpages to match the latest CLI options
* Tue Nov 10 2015 kpimenov@suse.com
- Update to version 0.2.29
  - bnc#954266 Silently ignore malformed lscpu lines instead of failing
* Fri Oct 30 2015 tschmidt@suse.com
- Update to version 0.2.28
  - Properly handle empty repository lists from zypper (bnc#951566)
* Fri Oct 23 2015 tschmidt@suse.com
- Update to version 0.2.27
  - Do not install recommended dependencies when installing the product release package (bnc#945462)
  - Addd --rollback option (fate#319114)
* Wed Oct 21 2015 vlewin@suse.com
- Update to version 0.2.26
  - zypper migration extremly slow with lot of modules and extensions registered (bnc#945462)
* Thu Oct 15 2015 hschmidt@suse.com
- Update to version 0.2.25
  - Solves Allow registration without system uid (dmidecode fails on qemu system) (bnc#934582)
* Mon Oct 12 2015 achernikov@suse.de
- bnc#949424 ensure version of SUSEConnect is bumped in order to be
  able to distinct requests from affected YaST version in SCC API
* Wed Sep 23 2015 hschmidt@suse.com
- Update to version 0.2.24
  - Bug 943451 - [Migration] failure when "zypper search" returns empty list
  - Bug 946488 - Synchronization API call returns "no implicit conversion of Symbol into Integer" error
  - Bug 941565 - zypper migration not using --releasever
  - Bug 945462 - zypper migration extremly slow with lot of modules and extensions registered
* Mon Sep 14 2015 vlewin@suse.com
- Update to version 0.2.23
  - Improve hwinfo detection on physical s390 systems
  - Bug 939293 - [S390] Error: Registration failed. Undefined method 'strip' for nil:NilClass (bnc#939293)
* Mon Sep 14 2015 vlewin@suse.com
- Update to version 0.2.22
  - Migration rollback (fate#319114)
  - [Migration rollback] zypper migrate: baseproduct mismatch (bnc#941303)
* Fri Aug  7 2015 vlewin@suse.com
- Update to version 0.2.21
  - Escape parameters of remove and add_repository methods
* Tue Aug  4 2015 vlewin@suse.com
- Update to version 0.2.20
  - Add find_products method to migration abstraction layer fate#319140
  - Fix add_service method which also creates the credentials files
* Fri Jul 31 2015 vlewin@suse.com
- Update to version 0.2.19
  - Introduction of migration abstraction layer for migration script
  - Clean up and re-factoring of yast abstraction layer
* Mon Jun 15 2015 vlewin@suse.com
- Update to version 0.2.18
  - Improve SUSEConnect error messages
  - New --cleanup option (remove old system credentials and all zypper services installed by SUSEConnect)
  - New --namespace option (forward SMT staging environment to proxy registration server)
* Wed May 20 2015 kpimenov@suse.de
- Update to version 0.2.17
  - Added migrations endpoint support for Yast
  - Use C locale for all the syscalls (solves output parsing issues in some locales)
  - Stripping UUID from SCC API calls if it is not settable
  - Moved examples from gist to project
* Wed Dec  3 2014 achernikov@suse.de
- Update to version 0.2.16
  - In case of wrong regcode provide meaningful message back to
    the user (Wrong regcode in that case).
* Mon Oct 20 2014 wstephenson@suse.com
- Update to version 0.2.15
  - Always write config file when --url parameter used (bnc#900689)
* Tue Sep 30 2014 vlewin@suse.com
- Update to version 0.2.14
  - fix SUSEConnect parameter usage from config file (bnc#899166)
  - use API version v4
* Tue Sep 23 2014 tschmidt@suse.com
- Update to version 0.2.13
  - Fix help message (bnc#897528)
  - Don't get stuck when zypper goes into interactive mode, fail instead.
    (bnc#897054, bnc#897056)
* Mon Sep 15 2014 wstephenson@suse.com
- Update to version 0.2.12
  - Output useful error message if the system was manually deleted
    on the registration server, leaving stale credentials.
* Fri Sep  5 2014 wstephenson@suse.com
- Update to version 0.2.11
  - Use v3 of the SCC api; adds product_type to product listing
  - Add --write-config option to persist settings with
  - Include distro_garget and instance_data in system update
    (bnc#889778)
  - Package build fixes
* Thu Aug 21 2014 wstephenson@suse.com
- Update to version 0.2.10
  - Better handing of zypper errors on the command line
  - Better error message if --instance-data file not found
  - Error out if invalid command line options given
* Tue Aug 12 2014 vlewin@suse.com
- Update to version 0.2.9
  - Fix for bnc #890881 On paravirtual Xen guests there is no dmi information,
    thus dmidecode fails. Instead a UUID is generated by the hypervisor and made available
    in /sys/hypervisor/uuid use this value for registration.
* Wed Aug  6 2014 vlewin@suse.com
- Update to version 0.2.8
  - S390 support
  - fix for bnc#889869 SCC registration during installation failed by reason
    that the IP address can not be handled by Yast for submitting to server
* Fri Jul 25 2014 wstephenson@suse.com
- Update to version 0.2.7
  - Respect LANG environment variable for error messages only
  - drop --language command line option
- Update integration tests
* Wed Jul 16 2014 achernikov@suse.de
- Update to version 0.2.6
  - close bnc#885957 (use proxy credentials from .curlrc file)
* Wed Jul 16 2014 tschmidt@suse.com
- Add machine readable output (json format) to status call
* Tue Jul 15 2014 mrueckert@suse.de
- added gem2rpm.yml and regenerated the spec file with it
* Thu Jul 10 2014 achernikov@suse.de
- Update to version 0.2.4
  - change the way we collect arch info. Former way `lscpu`, now
  `uname -i`
* Thu Jul 10 2014 achernikov@suse.de
- Update to version 0.2.3
  - Collect UUID on x86 platforms and send it to registration server
  as a part of hwinfo hash
* Mon Jul  7 2014 achernikov@suse.de
- Update to version 0.2.2
  - Set timeout of http interaction to 60 seconds
* Thu Jul  3 2014 jschmid@suse.com
- Added message on successful registration
- moved packaging path from bin to sbin
- added root check[security]
* Mon Jun 30 2014 achernikov@suse.de
- Updated to version 0.2.0 which from now on by minor version will
  represent api version which package implemented
  - added status call allowing to get registration status from the
  system
* Tue Jun 17 2014 achernikov@suse.de
- Update to version 0.1.2
  - Fixed certificate import issue bnc#883006
  - Abstract certificate interaction into YaST module layer
* Fri Jun 13 2014 achernikov@suse.de
- Update to version 0.1.1
  - Zypper now is Module (ex-class) holding the same functionality
  - Autorefresh and Enabled flags are respected by libzypp from now
  on, therefore we don't need them. Removed from activate/upgrade
  calls
  - activate/upgrade call does not contain subscription status
  anymore
  - activate/upgrade call does not contain per service credentials
  - activate/upgrade call is now object, not array
  - extensions call replaced with product show
  - YaST module adapted to recent underlying changes in connect
  - Connect::Client has list_products method renamed to show_product
  - SUSE::Connect::Remote::Product SUSE::Connect::Zypper::Product
  classes introduced to hold specific to origin logic
  - Zypper commands now using Open3 to properly operate on system
  commands
  - YaST module now requires Remote::Product object with
  identifier, version, arch for most operations
* Fri Jun  6 2014 wstephenson@suse.com
- Update to version 0.0.20
  - Allow gem to write persistent settings to config file
* Wed Jun  4 2014 tschmidt@suse.com
- Update to version 0.0.19
  - Include nested extensions in products() return
* Wed May 28 2014 wstephenson@suse.com
- Update to version 0.0.18
  - Rename --verbose CLI option to --debug
  - Standardise and document error codes
  - SUSEConnect(5) config file man page
  - Move main manpage to section 8
  - Add method to gem for product upgrades
  - Defer call to zypper during initialization for YaST
  - Add unit tests to disclose accidental calls to zypper
* Fri May 16 2014 wstephenson@suse.com
- Update to version 0.0.17
  - Introduce API versioning header for forward compatibility
  - Improve man page
* Thu May 15 2014 wstephenson@suse.com
- Update to version 0.0.16
  - Include EULA URL in products (API)
  - Improve --help output
* Wed Apr 30 2014 wstephenson@suse.com
- Add support for SHA256 SSL fingerprints
* Tue Apr 29 2014 wstephenson@suse.com
- Update to version 0.0.15
  - Made Client a useful entry point for YaST to use gem
  - Made use of zypper optional for YaST
  - added customizable verify_callback for HTTP connection
    (by default logs SSL errors)
  - send email when activating product
* Mon Apr 14 2014 achernikov@suse.de
- Client will accept given login received from API
* Mon Apr  7 2014 achernikov@suse.de
- Do not require regcode. API server will throw appropriate error
  if that is required in particular case
* Fri Mar 14 2014 mc@suse.de
- Send product release_type and distro_target from activate and
  announce calls respectively
* Thu Mar  6 2014 achernikov@suse.de
- Added products call allowing to get all publicly available
  products
* Fri Feb 28 2014 achernikov@suse.de
- Announce call now sending hostname alongside with main payload
* Tue Feb 25 2014 achernikov@suse.de
- add ca-certificates as a required package
* Mon Feb 24 2014 achernikov@suse.de
- token parameter replaced by regcode parameter
* Sat Feb 22 2014 achernikov@suse.de
- Conforming with new zypper products output structure for SLE12
* Fri Feb 14 2014 bamboo@suse.com
- Add license file
* Mon Feb 10 2014 tschmidt@suse.com
- Initial version
  SUSE Connect is a utility to register a system with the SUSE Customer Center.
  This package provides a command line tool and rubygem library for connecting a client system
  to the SUSE Customer Center. It will connect the system to your product subscriptions and enable
  the product repositories/services locally.
